performActionOnNotification method

void performActionOnNotification(
  1. dynamic message
)

We want to perform same action of the click of the notification. So this common method will be called on tap of any notification (onLaunch / onMessage / onResume)

Implementation

void performActionOnNotification(message) {
  //NotificationsBloc.instance.newNotification(message);
  logCat(message);
}